kvarn::prelude::utils::prelude::compact_str::core::str

Struct Utf8Error

1.6.0 · source
pub struct Utf8Error { /* private fields */ }
Errors which can occur when attempting to interpret a sequence of u8 as a string.

As such, the from_utf8 family of functions and methods for both Strings and &strs make use of this error, for example.

Examples

This error type’s methods can be used to create functionality similar to String::from_utf8_lossy without allocating heap memory:

fn <